API-docs
========
This section contains the Documentation of the Application Programming
Interface (API) of 'pcrglobwb_utils'.

There are function to load (meta-)data of observations from file:

.. toctree::
    :maxdepth: 1

    obs_data.rst

And others to read timeseries from nc-files:

.. toctree::
    :maxdepth: 1

    nc_data.rst

To ensemble an ensemble of timeseries:

.. toctree::
    :maxdepth: 1

    ensemble.rst

For assessments of temporal statistics and aggregation:

.. toctree::
    :maxdepth: 1

    time_funcs.rst

For analysing the water balance components:

.. toctree::
    :maxdepth: 1

    water_balance.rst
    
For validating against a range of datasets (GLEAM, GRACE):

.. toctree::
    :maxdepth: 1

    validation.rst

    